@@ -1,6 +1,6 @@
 class PnWKitException(Exception):
-    pass
+    ...
 
 
 class GraphQLError(PnWKitException):
-    pass
+    ...
